@@ -12,9 +12,8 @@ import re
 def _standardize_item(d, key, value):
     if type_util.is_string(key):
         # https://stackoverflow.com/a/12867228/2096218
-        norm_key = re.sub(
-            r'((?<=[a-z0-9])[A-Z]|(?!^)[A-Z](?=[a-z]))', r'_\1', key)
-        norm_key = slugify(norm_key, separator='_')
+        norm_key = re.sub(r"((?<=[a-z0-9])[A-Z]|(?!^)[A-Z](?=[a-z]))", r"_\1", key)
+        norm_key = slugify(norm_key, separator="_")
         rename(d, key, norm_key)
 
 
