@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import absolute_import
-
 from benedict.serializers.abstract import AbstractSerializer
 from benedict.utils import type_util
 
-from six import text_type
-
 import json
 
 
 class JSONSerializer(AbstractSerializer):
+    """
+    This class describes a json serializer.
+    """
 
     def __init__(self):
         super(JSONSerializer, self).__init__()
@@ -20,8 +19,7 @@ class JSONSerializer(AbstractSerializer):
         return data
 
     def encode(self, d, **kwargs):
-        kwargs.setdefault('default', self._encode_default)
-        kwargs.setdefault('sort_keys', True)
+        kwargs.setdefault("default", self._encode_default)
         data = json.dumps(d, **kwargs)
         return data
 
@@ -31,5 +29,5 @@ class JSONSerializer(AbstractSerializer):
         elif type_util.is_datetime(obj):
             return obj.isoformat()
         elif type_util.is_decimal(obj):
-            return text_type(obj)
-        return text_type(obj)
+            return str(obj)
+        return str(obj)
